Module charts

Module charts 

Chart builder methods for configuring visual properties.

Each chart type (line, scatter, bar, histogram, fill_between, step, stem, boxplot, errorbar, heatmap, pie, violin, contour, polar, hexbin, waterfall) has builder methods implemented directly on its artist type.

Modules

bar
Bar chart builder methods.
boxplot
Box plot builder methods.
contour
Contour and filled contour chart builder methods.
errorbar
Error bar chart builder methods.
fill_between
Fill-between chart builder methods.
heatmap
Heatmap chart builder methods.
hexbin
Hexbin chart builder methods.
histogram
Histogram chart builder methods and binning utilities.
line
Line chart builder methods.
pie
Pie chart builder methods.
polar
Polar plot builder methods.
scatter
Scatter chart builder methods.
stem
Stem chart builder methods.
step
Step chart builder methods.
violin
Violin plot builder methods and kernel density estimation.
waterfall
Waterfall chart builder methods.