pub enum HAlign {
Left,
Center,
Right,
}Expand description
Horizontal text alignment.
Variants
Left
Align the left edge of the text to the anchor point.
Center
Center the text horizontally on the anchor point.
Right
Align the right edge of the text to the anchor point.