pub enum VAlign {
Top,
Middle,
Bottom,
Baseline,
}Expand description
Vertical text alignment.
Variants
Top
Align the top of the text bounding box to the anchor point.
Middle
Center the text vertically on the anchor point.
Bottom
Align the bottom of the text bounding box to the anchor point.
Baseline
Align the text baseline to the anchor point.