Data series abstraction for chart input.
Structs
- Categories
- Categorical labels for bar charts, pie charts, and other discrete-axis visualizations.
- Series
- A sequence of
f64values representing one dimension of chart data.
Traits
- Into
Categories - Trait for types that can be converted into
Categories. - Into
Series - Trait for types that can be converted into a
Series.