Annotation

Struct Annotation 

pub struct Annotation {
    pub text: String,
    pub xy: (f64, f64),
    pub xytext: (f64, f64),
    pub fontsize: Option<f64>,
    pub color: Option<Color>,
    pub ha: HAlign,
    pub va: VAlign,
    pub arrowstyle: ArrowStyle,
    pub arrow_color: Option<Color>,
}
An annotation with optional arrow from a text position to a data point.

Created by [Axes::annotate]. The text is drawn at xytext and, when an arrow style other than ArrowStyle::None is set, an arrow is drawn from xytext to xy.

Fields

text: String

The annotation text string.

xy: (f64, f64)

The data-space point being annotated.

xytext: (f64, f64)

The data-space position where the text is placed.

fontsize: Option<f64>

Optional font size override (in points). None uses the theme default.

color: Option<Color>

Optional text color override. None uses the theme text color.

ha: HAlign

Horizontal alignment of the text relative to xytext.

va: VAlign

Vertical alignment of the text relative to xytext.

arrowstyle: ArrowStyle

The style of arrow drawn from xytext to xy.

arrow_color: Option<Color>

Optional arrow color override. None uses the text color.

Implementations

Source

impl Annotation

pub fn fontsize(&mut self, size: f64) -> &mut Self

Sets the font size (in points).

pub fn color(&mut self, color: Color) -> &mut Self

Sets the text color.

pub fn ha(&mut self, ha: HAlign) -> &mut Self

Sets the horizontal alignment.

pub fn va(&mut self, va: VAlign) -> &mut Self

Sets the vertical alignment.

pub fn arrowstyle(&mut self, style: ArrowStyle) -> &mut Self

Sets the arrow style.

pub fn arrow_color(&mut self, color: Color) -> &mut Self

Sets the arrow color.