pub struct ErrorBarArtist {
pub x: Series,
pub y: Series,
pub xerr: Option<ErrorBarData>,
pub yerr: Option<ErrorBarData>,
pub color: Color,
pub label: Option<String>,
pub cap_size: f64,
pub line_width: f64,
}Expand description
An error bar plot showing data points with uncertainty bars.
Each data point (x, y) can have optional horizontal (xerr) and/or
vertical (yerr) error bars. The error bars are drawn as lines with
optional caps at the ends.
Fields
x: SeriesX-coordinates of the data points.
y: SeriesY-coordinates of the data points.
xerr: Option<ErrorBarData>Optional x-axis error data.
yerr: Option<ErrorBarData>Optional y-axis error data.
color: ColorColor for the center line, error bars, and caps.
label: Option<String>Optional legend label.
cap_size: f64Cap size in pixels for the error bar ends.
line_width: f64Stroke width of the error bar lines and caps.
Implementations
Sourceimpl ErrorBarArtist
impl ErrorBarArtist
Sourcepub fn line_width(&mut self, width: f64) -> &mut Self
pub fn line_width(&mut self, width: f64) -> &mut Self
Sourcepub fn yerr_symmetric(self, errs: &[f64]) -> Self
pub fn yerr_symmetric(self, errs: &[f64]) -> Self
Sourcepub fn yerr_asymmetric(self, low: &[f64], high: &[f64]) -> Self
pub fn yerr_asymmetric(self, low: &[f64], high: &[f64]) -> Self
Sourcepub fn xerr_symmetric(self, errs: &[f64]) -> Self
pub fn xerr_symmetric(self, errs: &[f64]) -> Self
Sourcepub fn xerr_asymmetric(self, low: &[f64], high: &[f64]) -> Self
pub fn xerr_asymmetric(self, low: &[f64], high: &[f64]) -> Self