Module series

Module series 

Data series abstraction for chart input.

Structs

Categories
Categorical labels for bar charts, pie charts, and other discrete-axis visualizations.
Series
A sequence of f64 values representing one dimension of chart data.

Traits

IntoCategories
Trait for types that can be converted into Categories.
IntoSeries
Trait for types that can be converted into a Series.