Axis tick generation using the Talbot/Wilkinson extended algorithm.
This module implements the “An Extension of Wilkinson’s Algorithm for Positioning Tick Labels on Axes” algorithm (Talbot, Lin, Hanrahan, 2010). It produces aesthetically pleasing tick positions by jointly optimizing four objectives: simplicity, coverage, density, and legibility.
Structs
- Tick
- A single tick mark with its position in data space and a formatted label.
- TickSet
- A set of tick positions with formatted labels.
Functions
- generate_
ticks - Generates optimal tick positions for an axis range.